@@ -30,17 +30,17 @@ extern "C" {
 #define MagickLibVersion  0x712
 #define MagickLibVersionText  "7.1.2"
 #define MagickLibVersionNumber  10,0,2
-#define MagickLibAddendum  "-5"
+#define MagickLibAddendum  "-6 (Beta)"
 #define MagickLibInterface  10
 #define MagickLibMinInterface  10
 #define MagickPlatform  "x86_64"
 #define MagickppLibVersionText  "7.1.2"
 #define MagickppLibVersionNumber  5:0:0
-#define MagickppLibAddendum  "-5"
+#define MagickppLibAddendum  "-6 (Beta)"
 #define MagickppLibInterface  5
 #define MagickppLibMinInterface  5
-#define MagickGitRevision  "7d94ecf41:20251005"
-#define MagickReleaseDate  "2025-10-05"
+#define MagickGitRevision  "4a620c2a8:20251006"
+#define MagickReleaseDate  "2025-10-06"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
